summaryrefslogtreecommitdiff
path: root/arch/sparc/linux_process.hh
diff options
context:
space:
mode:
authorGabe Black <gblack@eecs.umich.edu>2006-03-01 05:28:26 -0500
committerGabe Black <gblack@eecs.umich.edu>2006-03-01 05:28:26 -0500
commitb71f9c801eb869b477a1e5a6f12498862efbb886 (patch)
treeeb86f28bcacc5f64a233cbcf6587fc1410fa3e87 /arch/sparc/linux_process.hh
parent2eff368dd03c93a503e13ab82cf4c4abb0c06aa9 (diff)
downloadgem5-b71f9c801eb869b477a1e5a6f12498862efbb886.tar.xz
Begain setting up syscall emulation for sparc linux.
arch/sparc/linux_process.cc: Began modifying this file for sparc, and replaced the alpha syscall numbers with the sparc ones. arch/sparc/linux_process.hh: Begain modifying this file for sparc. --HG-- extra : convert_revision : b1ed8ac50a35591521c5feaf1ea9c4b8ccc26dc8
Diffstat (limited to 'arch/sparc/linux_process.hh')
-rw-r--r--arch/sparc/linux_process.hh10
1 files changed, 5 insertions, 5 deletions
diff --git a/arch/sparc/linux_process.hh b/arch/sparc/linux_process.hh
index 7de1b1ac1..c41406b4b 100644
--- a/arch/sparc/linux_process.hh
+++ b/arch/sparc/linux_process.hh
@@ -26,18 +26,18 @@
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
-#ifndef __ALPHA_LINUX_PROCESS_HH__
-#define __ALPHA_LINUX_PROCESS_HH__
+#ifndef __SPARC_LINUX_PROCESS_HH__
+#define __SPARC_LINUX_PROCESS_HH__
#include "sim/process.hh"
-/// A process with emulated Alpha/Linux syscalls.
-class AlphaLinuxProcess : public LiveProcess
+/// A process with emulated SPARC/Linux syscalls.
+class SparcLinuxProcess : public LiveProcess
{
public:
/// Constructor.
- AlphaLinuxProcess(const std::string &name,
+ SparcLinuxProcess(const std::string &name,
ObjectFile *objFile,
int stdin_fd, int stdout_fd, int stderr_fd,
std::vector<std::string> &argv,